@@ -592,7 +592,7 @@ class PDFWriter(writers.Writer):
             try:
                 template = jinja_env.get_template(self.config.pdf_cover_template)
             except jinja2.TemplateNotFound:
-                log.error("Can't find cover template %s, using default"%self.custom_cover)
+                log.error("Can't find cover template %s, using default"%self.config.pdf_cover_template)
                 template = jinja_env.get_template('sphinxcover.tmpl')
 
             # This is what's used in the python docs because
@@ -903,8 +903,8 @@ def setup(app):
     app.add_config_value('pdf_extensions',['vectorpdf'], None)
     app.add_config_value('pdf_page_template','cutePage', None)
     app.add_config_value('pdf_invariant',False, None)
-    app.add_config_value('pdf_real_footnotes','False', None)
-    app.add_config_value('pdf_use_toc','True', None)
+    app.add_config_value('pdf_real_footnotes',False, None)
+    app.add_config_value('pdf_use_toc',True, None)
     app.add_config_value('pdf_toc_depth',9999, None)
     app.add_config_value('pdf_use_numbered_links',False, None)
     app.add_config_value('pdf_fit_background_mode',"scale", None)
